@@ -63,7 +63,9 @@ class LoggerWrapper(object):
         self._log('TRACE', message, data)
 
     def debug(self, message, data={}):
-        self._log('DEBUG', message, data)
+        # Validar si esta modo productivo.
+        if os.environ.get('PRODUCTION', False):
+            self._log('DEBUG', message, data)
 
     def info(self, message, data={}):
         self._log('INFO', message, data)
